summaryrefslogtreecommitdiffstats
path: root/src/include/usr/hwas/common
diff options
context:
space:
mode:
authorBrian Horton <brianh@linux.ibm.com>2014-06-20 16:42:24 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2014-06-30 09:30:59 -0500
commitf555d057b419d1c6708b01437564ea4ab31ef4ce (patch)
treeea05a3c39ec8b98fdd9af96212a6d0ccf025190b /src/include/usr/hwas/common
parent9c4aa90f178a4f9ed68bdb0d17eec52785c5ea47 (diff)
downloadtalos-hostboot-f555d057b419d1c6708b01437564ea4ab31ef4ce.tar.gz
talos-hostboot-f555d057b419d1c6708b01437564ea4ab31ef4ce.zip
add 'did we really deconfigure the target' parameter
Change-Id: Id1e1639f49223d4fc25493453a9897d0ce7adb90 CQ: SW259741 Co-req: 925271 Backport: release-fips811 Reviewed-on: http://gfw160.aus.stglabs.ibm.com:8080/gerrit/11736 Tested-by: Jenkins Server Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/include/usr/hwas/common')
-rw-r--r--src/include/usr/hwas/common/deconfigGard.H12
1 files changed, 9 insertions, 3 deletions
diff --git a/src/include/usr/hwas/common/deconfigGard.H b/src/include/usr/hwas/common/deconfigGard.H
index 971fb5973..e32170e20 100644
--- a/src/include/usr/hwas/common/deconfigGard.H
+++ b/src/include/usr/hwas/common/deconfigGard.H
@@ -239,14 +239,17 @@ public:
* and the function continues. The only errors returned are usage errors.
* By default, targets are NOT deconfigured if the system is at Runtime.
*
* @param[in] i_target Reference to Target to deconfigure.
* @param[in] i_errlEid Error log EID to store in Deconfigure Record.
* @param[in] i_runTimeDeconfigRule Deconfigure Runtime options -
* default not at runtime
* @return errlHndl_t. Error log handle.
*/
errlHndl_t deconfigureTarget(TARGETING::Target & i_target,
const uint32_t i_errlEid,
+ bool *o_targetDeconfigured = NULL,
const DeconfigureRuntime i_runTimeDeconfigRule =
NOT_AT_RUNTIME);
@@ -425,11 +428,14 @@ private:
*
* @param[in] i_target Reference to Target to deconfigure.
* @param[in] i_errlEid Error log EID to store in Deconfigure Record.
+ * @param[out] o_targetDeconfigured - if pointer is valid, bool is set
+ * to true if target was deconfigured; NOT SET OTHERWISE
* @param[in] i_runTimeDeconfigRule Deconfigure Runtime options -
* default not at runtime
*/
void _deconfigureTarget(TARGETING::Target & i_target,
const uint32_t i_errlEid,
+ bool *o_targetDeconfigured = NULL,
const DeconfigureRuntime i_runTimeDeconfigRule =
NOT_AT_RUNTIME);
OpenPOWER on IntegriCloud
@@ -239,14 +239,17 @@ public:
* By default, targets are NOT deconfigured if the system is at Runtime.
*
- * @param[in] i_target Reference to Target to deconfigure.
- * @param[in] i_errlEid Error log EID to store in Deconfigure Record.
- * @param[in] i_runTimeDeconfigRule Deconfigure Runtime options -
+ * @param[in] i_target Reference to Target to deconfigure.
+ * @param[in] i_errlEid Error log EID to store in Deconfigure Record.
+ * @param[out] o_targetDeconfigured - if pointer is valid, bool is set
+ * to true if target was deconfigured; NOT SET OTHERWISE
+ * @param[in] i_runTimeDeconfigRule Deconfigure Runtime options -
* default not at runtime
* @return errlHndl_t. Error log handle.